#   Licensed under the Apache License, Version 2.0 (the "License"); you may
#   not use this file except in compliance with the License. You may obtain
#   a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#   License for the specific language governing permissions and limitations
#   under the License.
#

import logging
from nectarclient_lib import exceptions
from osc_lib.command import command


class SendMessage(command.ShowOne):
    """Send message"""

    log = logging.getLogger(__name__ + '.SendMessage')

    def get_parser(self, prog_name):
        parser = super(SendMessage, self).get_parser(prog_name)
        parser.add_argument(
            '--recipient',
            required=True,
            metavar='<recipient>',
            help="Email address of the recipient"
        )
        parser.add_argument(
            '--subject',
            metavar='<subject>',
            required=True,
            help="Email subject"
        )
        parser.add_argument(
            '--body',
            required=True,
            metavar='<body>',
            help='Email body',
        )
        parser.add_argument(
            '--cc',
            action='append',
            metavar='<cc>',
            default=[],
            help='Carbon Copy recipient.\
                 To add multiple CC\'s specify this option multiple times'
        )

        return parser

    def take_action(self, parsed_args):
        self.log.debug('take_action(%s)', parsed_args)
        client = self.app.client_manager.taynac
        try:
            data = client.messages.send(parsed_args.subject,
                                        parsed_args.body,
                                        parsed_args.recipient,
                                        parsed_args.cc)
        except Exception as ex:
            raise exceptions.CommandError(str(ex))

        return self.dict2columns(data.to_dict())



#   Licensed under the Apache License, Version 2.0 (the "License"); you may
#   not use this file except in compliance with the License. You may obtain
#   a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#   License for the specific language governing permissions and limitations
#   under the License.
#

from nectarclient_lib.tests.unit import utils

from taynacclient.tests.unit.v1 import fakes


class MessageTest(utils.TestCase):

    def setUp(self):
        super(MessageTest, self).setUp()
        self.cs = fakes.FakeClient()

    def test_send(self):
        response = self.cs.messages.send(
            subject="Test", body="Hi",
            recipient="bob@example.com",
            cc=["jack@example.com"])
        self.cs.assert_called('POST', '/v1/message/')
        self.assertEqual(fakes.generic_message['backend_id'],
                         response.backend_id)



#   Licensed under the Apache License, Version 2.0 (the "License"); you may
#   not use this file except in compliance with the License. You may obtain
#   a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#   License for the specific language governing permissions and limitations
#   under the License.
#

from nectarclient_lib import base


class Message(base.Resource):

    def __repr__(self):
        return "<Message %s>" % self._info


class MessageManager(base.Manager):

    base_url = 'v1/message'
    resource_class = Message

    def send(self, subject, body, recipient, cc=[]):
        data = {'subject': subject, 'body': body,
                'recipient': recipient, 'cc': cc}
        url = '/%s/' % (self.base_url)
        return self._post(url, data=data)



#!/usr/bin/env python

import setuptools

from pbr.packaging import parse_requirements

entry_points = {
    'openstack.cli.extension':
    ['taynac = taynacclient.osc.plugin'],
    'openstack.taynac.v1':
    [
        'message send = taynacclient.osc.v1.messages:SendMessage',
    ]
}


setuptools.setup(
    name='taynacclient',
    version='1.2.0',
    description=('Client for the taynac system'),
    author='Sam Morrison',
    author_email='sorrison@gmail.com',
    url='https://github.com/NeCTAR-RC/python-taynacclient',
    packages=[
        'taynacclient',
    ],
    include_package_data=True,
    setup_requires=['pbr>=3.0.0'],
    install_requires=parse_requirements(),
    license="Apache",
    zip_safe=False,
    classifiers=(
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
    ),
    entry_points=entry_points,
)
